@@ -26,6 +26,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "gth-folder-selection-dialog.h"
 
 #include "bookmark-list.h"
@@ -261,7 +262,7 @@ file_sel_ok_clicked_cb (GtkDialog  *file_sel,
 			gpointer    data)
 {
 	GthFolderSelection *folder_sel;
-	char               *folder;
+	char               *esc_folder;
 
 	if (button_number != GTK_RESPONSE_ACCEPT) {
 		gtk_widget_destroy (GTK_WIDGET (file_sel));
@@ -270,12 +271,16 @@ file_sel_ok_clicked_cb (GtkDialog  *file_sel,
 
 	folder_sel = g_object_get_data (G_OBJECT (file_sel), "folder_sel");
 	
-	folder = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel));
-	gth_folder_selection_set_folder (folder_sel, folder);
+	esc_folder = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel));
+	if (esc_folder != NULL) {
+		char *folder = gnome_vfs_unescape_string (esc_folder, "");
+		gth_folder_selection_set_folder (folder_sel, folder);
+		g_free (folder);
+	}
 
 	gtk_widget_destroy (GTK_WIDGET (file_sel));
 
-	g_free (folder);
+	g_free (esc_folder);
 }
 
 
@@ -585,7 +590,14 @@ gth_folder_selection_set_folder (GthFolderSelection *fsel,
 char *
 gth_folder_selection_get_folder (GthFolderSelection *fsel)
 {
-	return _gtk_entry_get_filename_text (GTK_ENTRY (fsel->priv->file_entry));
+	char *value;
+	char *retval;
+	
+	value = _gtk_entry_get_filename_text (GTK_ENTRY (fsel->priv->file_entry));
+	retval = gnome_vfs_unescape_string (value, "");
+	g_free (value);
+	
+	return retval;
 }
 
 
