@@ -525,7 +525,7 @@ real_load_current_image (GthFullscreen *fullscreen)
 
 		if ((priv->image != NULL) 
 		    && (priv->image_path != NULL) 
-		    && (strcmp (priv->image_path, filename) == 0))
+		    && same_uri (priv->image_path, filename))
 			image_viewer_set_pixbuf (IMAGE_VIEWER (priv->viewer), priv->image);
 
 		else {
@@ -534,8 +534,7 @@ real_load_current_image (GthFullscreen *fullscreen)
 			gthumb_preloader_start (priv->preloader,
 						priv->requested_path,
 						get_image_filename (get_next_image (fullscreen)),
-						get_image_filename (get_prev_image (fullscreen)),
-						NULL);
+						get_image_filename (get_prev_image (fullscreen)));
 			from_pixbuf = FALSE;
 		}
 
@@ -601,7 +600,7 @@ load_first_or_last_image (GthFullscreen *fullscreen,
 		} else if (priv->image_path != NULL)
 			priv->current = g_list_find_custom (priv->file_list, 
 							    priv->image_path,
-							    (GCompareFunc) strcmp);
+							    (GCompareFunc) uricmp);
 		
 		if (priv->current == NULL)
 			priv->current = priv->file_list;
@@ -612,7 +611,7 @@ load_first_or_last_image (GthFullscreen *fullscreen,
 	    && (priv->slideshow_direction != GTH_DIRECTION_RANDOM)) 
 		priv->current = g_list_find_custom (priv->file_list, 
 						    priv->image_path,
-						    (GCompareFunc) strcmp);
+						    (GCompareFunc) uricmp);
 
 	load_current_image (fullscreen);
 }
@@ -812,7 +811,7 @@ pos_from_path (GList      *list,
 
 	for (scan = list; scan; scan = scan->next) {
 		char *l_path = scan->data;
-		if (strcmp (l_path, path) == 0)
+		if (same_uri (l_path, path))
 			return i;
 		i++;
 	}
@@ -1096,7 +1095,7 @@ viewer_key_press_cb (GtkWidget   *widget,
 	GtkAction     *a;
 
 	if ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK) {
-		switch (event->keyval) {
+		switch (gdk_keyval_to_lower (event->keyval)) {
 			/* Exit fullscreen mode. */
 		case GDK_w:
 			gth_window_close (window);
@@ -1111,7 +1110,7 @@ viewer_key_press_cb (GtkWidget   *widget,
 	}
 
 
-	switch (event->keyval) {
+	switch (gdk_keyval_to_lower (event->keyval)) {
 
 		/* Exit fullscreen mode. */
 	case GDK_Escape:
@@ -1368,7 +1367,7 @@ delete_list_from_file_list (GthFullscreen *fullscreen,
 		
 		deleted = g_list_find_custom (fullscreen->priv->file_list, 
 					      filename,
-					      (GCompareFunc) strcmp);
+					      (GCompareFunc) uricmp);
 		if (deleted != NULL) {
 			if (fullscreen->priv->current == deleted) {
 				reload_current_image = TRUE;
@@ -1407,7 +1406,7 @@ monitor_update_files_cb (GthMonitor      *monitor,
 		if ((fullscreen->priv->image_path != NULL) 
 		    && (g_list_find_custom (list, 
 					    fullscreen->priv->image_path,
-					    (GCompareFunc) strcmp) != NULL)) {
+					    (GCompareFunc) uricmp) != NULL)) {
 			g_free (fullscreen->priv->image_path);
 			fullscreen->priv->image_path = NULL;
 			if (fullscreen->priv->image != NULL)
@@ -1416,7 +1415,7 @@ monitor_update_files_cb (GthMonitor      *monitor,
 		if ((fullscreen->priv->current != NULL) 
 		    && (g_list_find_custom (list, 
 					    fullscreen->priv->current->data,
-					    (GCompareFunc) strcmp) != NULL))
+					    (GCompareFunc) uricmp) != NULL))
 			load_current_image (fullscreen);
 		break;
 
@@ -1440,7 +1439,7 @@ monitor_file_renamed_cb (GthMonitor    *monitor,
 
 	renamed_image = g_list_find_custom (fullscreen->priv->file_list,
 					    old_name,
-					    (GCompareFunc) strcmp);
+					    (GCompareFunc) uricmp);
 
 	if (renamed_image == NULL)
 		return;
@@ -1451,7 +1450,7 @@ monitor_file_renamed_cb (GthMonitor    *monitor,
 	if (fullscreen->priv->image_path == NULL)
 		return;
 
-	if (strcmp (old_name, fullscreen->priv->image_path) != 0)
+	if (! same_uri (old_name, fullscreen->priv->image_path))
 		return;
 
 	g_free (fullscreen->priv->image_path);
@@ -1621,6 +1620,8 @@ create_toolbar_window (GthFullscreen *fullscreen)
 	/**/
 
 	priv->toolbar_window = gtk_window_new (GTK_WINDOW_POPUP);
+	gtk_window_set_screen (GTK_WINDOW (priv->toolbar_window),
+			       gtk_widget_get_screen (priv->viewer));
 	gtk_window_set_default_size (GTK_WINDOW (priv->toolbar_window),
 				     gdk_screen_get_width (gtk_widget_get_screen (priv->toolbar_window)),
 				     -1);
